.. image:: https://forge.ird.fr/phim/sravel/snakecdysis/-/blob/59b3b5fae593e786562e28cad9fa19a31d0ebdae/docs/source/_images/Snakecdysis_logo.png
   :target: https://forge.ird.fr/phim/sravel/snakecdysis/-/blob/59b3b5fae593e786562e28cad9fa19a31d0ebdae/docs/source/_images/Snakecdysis_logo.png
   :align: center
   :alt: Snakecdysis Logo

|PythonVersions| |SnakemakeVersions| |Downloads|

.. contents:: Table of Contents
    :depth: 2

About Snakecdysis
=================

|readthedocs|

**Homepage:** `https://snakecdysis.readthedocs.io/en/latest/ <https://snakecdysis.readthedocs.io/en/latest/>`_


You want to wrapped your best snakemake workflow to be easy install and run, Snakecdysis is for you !!!!!

Citation
========

https://forge.ird.fr/phim/sravel/Snakecdysis

Authors
=======

* Sébastien RAVEL (CIRAD).

Thanks
======

Thanks to Valentin Guignon how find the name
Thanks to CulebrONT team's

License
=======

Licencied under `CeCill-C <http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html>`_ and GPLv3.

Intellectual property belongs to `CIRAD <https://www.cirad.fr/>`_ and authors.

.. |PythonVersions| image:: https://img.shields.io/badge/python-3.7%2B-blue
   :target: https://www.python.org/downloads

.. |SnakemakeVersions| image:: https://img.shields.io/badge/snakemake-≥6.10.0-brightgreen.svg
   :target: https://snakemake.readthedocs.io

.. |readthedocs| image:: https://pbs.twimg.com/media/E5oBxcRXoAEBSp1.png
   :target: https://snakecdysis.readthedocs.io/en/latest
   :width: 400px

.. |Downloads| image:: https://img.shields.io/pypi/dm/snakecdysis?color=orange&logo=snakecdysis-pypi
   :target: https://pypi.org/project/snakecdysis
   :alt: PyPi downloads
